==> ka-table-3.7.2.tgz: package/Components/DataRowContent/DataRowContent.tsx <==
import React from 'react';

import { getEditableCell } from '../../Utils/CellUtils';
import { getRowEditableCells } from '../../Utils/FilterUtils';
import CellComponent from '../CellComponent/CellComponent';
import { IRowCommonProps } from '../DataRow/DataRow';

export interface IDataRowProps extends IRowCommonProps {
  isDetailsRowShown: boolean;
  isSelectedRow: boolean;
}

const DataRowContent: React.FunctionComponent<IDataRowProps> = ({
  childAttributes,
  columns,
  dispatch,
  editableCells,
  editingMode,
  isDetailsRowShown,
  isSelectedRow,
  rowData,
  rowKeyField,
  rowKeyValue,
}) => {
  const rowEditableCells = getRowEditableCells(rowKeyValue, editableCells);
  return (
    <>
      {columns.map((column) => {
        const editableCell = getEditableCell(column, rowEditableCells);

        return (
          <CellComponent
            childAttributes={childAttributes}
            column={column}
            dispatch={dispatch}
            editingMode={editingMode}
            isEditableCell={!!editableCell}
            isDetailsRowShown={isDetailsRowShown}
            isSelectedRow={isSelectedRow}
            editorValue={editableCell && editableCell.editorValue}
            validationMessage={editableCell && editableCell.validationMessage}
            hasEditorValue={editableCell && editableCell.hasOwnProperty('editorValue')}
            key={column.key}
            rowData={rowData}
            rowKeyField={rowKeyField}
            rowKeyValue={rowKeyValue}
          />
        );
      })}
    </>
  );
};

export default DataRowContent;

==> ka-table-4.0.2.tgz: package/Components/DataRowContent/DataRowContent.tsx <==
import React from 'react';

import { IDataRowProps } from '../../props';
import { getEditableCell } from '../../Utils/CellUtils';
import { getValueByColumn } from '../../Utils/DataUtils';
import CellComponent from '../CellComponent/CellComponent';

const DataRowContent: React.FunctionComponent<IDataRowProps> = ({
  childComponents,
  columns,
  dispatch,
  editingMode,
  format,
  isDetailsRowShown,
  isSelectedRow,
  rowData,
  rowEditableCells,
  rowKeyField,
  rowKeyValue,
  validation,
}) => {
  return (
    <>
      {columns.map((column) => {
        const editableCell = getEditableCell(column, rowEditableCells);
        const hasEditorValue = editableCell && editableCell.hasOwnProperty('editorValue');
        const editorValue = editableCell && editableCell.editorValue;
        const value = hasEditorValue ? editorValue : getValueByColumn(rowData, column);
        return (
          <CellComponent
            childComponents={childComponents}
            column={column}
            dispatch={dispatch}
            editingMode={editingMode}
            editorValue={editorValue}
            format={format}
            hasEditorValue={editableCell && editableCell.hasOwnProperty('editorValue')}
            isDetailsRowShown={isDetailsRowShown}
            isEditableCell={!!editableCell}
            isSelectedRow={isSelectedRow}
            key={column.key}
            rowData={rowData}
            rowKeyField={rowKeyField}
            rowKeyValue={rowKeyValue}
            validation={validation}
            validationMessage={editableCell && editableCell.validationMessage}
            value={value}
          />
        );
      })}
    </>
  );
};

export default DataRowContent;
